@@ -15,6 +15,7 @@
 
 import os
 import sys
+import configparser
 
 # If your extensions are in another directory, add it here. If the directory
 # is relative to the documentation root, use os.path.abspath to make it
@@ -30,7 +31,9 @@ sys.path.insert(0, os.path.dirname(base_dir))
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = [
     'autodoc', 'sphinx.ext.todo', 'preprocess', 'sphinx.ext.ifconfig',
-    'sphinx.ext.viewcode', 'sphinx.ext.mathjax']
+    'sphinx.ext.viewcode', 'sphinx.ext.mathjax', 'sphinx.ext.extlinks']
+
+extlinks = {'repo': ('https://github.com/kivy/kivy/issues/%s', '#')}
 
 # Todo configuration
 todo_include_todos = True
@@ -68,7 +71,7 @@ release = kivy.__version__
 base = 'autobuild.py-done'
 if not os.path.exists(os.path.join(os.path.dirname(base_dir), base)):
     import autobuild
-import gallery
+from kivy.tools import gallery
 gallery.write_all_rst_pages()
 
 # There are two options for replacing |today|: either, you set today to some
@@ -216,22 +219,20 @@ latex_toplevel_sectioning = 'part'
 # If false, no module index is generated.
 # latex_use_modindex = True
 
-from kivy import setupconfig
+config_parser = configparser.ConfigParser()
+config_parser.read(os.path.join(base_dir, '..', '..', 'setup.cfg'))
 
+# if used in a code-block, the block has to be marked with
+# .. parse-literal::, otherwise it won't be replaced
+# !!! doesn't work for "::", ".. code::" or ".. code-block::"
+python_versions = config_parser['kivy']['python_versions'].strip()
 replacements = {
-    'cython_install': 'Cython==' + setupconfig.CYTHON_MAX,
-    'cython_note': (
-        'This version of **Kivy requires at least Cython version {0}**, '
-        'and has been tested through {1}. Later versions may work, '
-        'but as they have not been tested there is no guarantee.'
-    ).format(setupconfig.CYTHON_MIN, setupconfig.CYTHON_MAX)
+    'python_versions': python_versions,
+    'kivy_version': kivy.__version__,
+    'python_versions_bold': f'**{python_versions}**',
+    'kivy_version_bold': f'**{kivy.__version__}**',
 }
 
-if setupconfig.CYTHON_BAD:
-    replacements['cython_note'] += (' **The following versions of Cython have '
-                                    'known issues and cannot be used with Kivy'
-                                    ': {0}**').format(setupconfig.CYTHON_BAD)
-
 epilog = []
 
 for key, value in replacements.items():
